
utils::globalVariables(c(".",
                         'Estimate',
                         'Variable',
                         'Level',
                         'v.test',
                         'p.value',
                         'V1',
                         'V2',
                         "bin",
                         ".data"))
